Type Alias safe_vk::extract::Update

source ·
pub type Update<T = Value> = LongPollResponse<T>;

Aliased Type

struct Update<T = Value> {
    pub ts: Option<String>,
    pub updates: Option<Vec<Event<T>>>,
    pub failed: Option<i32>,
}

Fields

ts: Option<String>

The ID of the last event received. Used in the next request to fetch subsequent events.

updates: Option<Vec<Event<T>>>

A list of events that have occurred.

failed: Option<i32>

An error code indicating that the session needs to be refreshed or restarted.

Implementations

source

impl<T> Update<T>

source

pub fn into_parts(self) -> Parts