Struct safe_vk::responses::ButtonPressCallback
source · pub struct ButtonPressCallback<T> {
pub conversation_message_id: i32,
pub event_id: String,
pub payload: T,
pub peer_id: i32,
pub user_id: i32,
}Fields
conversation_message_id: i32The ID of the conversation message associated with the button press.
event_id: StringA unique identifier for this particular event occurrence.
payload: TAn object containing additional data sent with the button press. The structure of this object is defined by the button’s payload.
peer_id: i32The ID of the conversation (chat) where the button was pressed.
user_id: i32The user ID of the user who pressed the button.